<?php
/**
 * Plugin Name: Weengle Simple Contact Form Logger
 * Plugin URI: https://www.weengle.com/simple-contact-form-logger/
 * Description: A lightweight plugin to add a contact form and store submissions in the WordPress Database.
 * Version: 1.0
 * Author: Debasis Pradhan
 */

if (!defined('ABSPATH')) exit;

class WeengleContactFormLogger {

    public function __construct() {
        add_shortcode('weengle_contact_form', [$this, 'render_contact_form']);
        add_action('init', [$this, 'handle_form_submission']);
        add_action('admin_menu', [$this, 'create_admin_menu']);
        register_activation_hook(__FILE__, [$this, 'create_database_table']);
    }

    public function render_contact_form() {
        ob_start();
        ?>
        <form method="post">
            <p><input type="text" name="scfl_name" placeholder="Your Name" required></p>
            <p><input type="email" name="scfl_email" placeholder="Your Email" required></p>
            <p><textarea name="scfl_message" placeholder="Your Message" required></textarea></p>
            <p><input type="submit" name="scfl_submit" value="Send"></p>
        </form>
        <?php
        return ob_get_clean();
    }

    public function handle_form_submission() {
        if (isset($_POST['scfl_submit'])) {
            global $wpdb;
            $table_name = $wpdb->prefix . 'scfl_submissions';

            $name = sanitize_text_field($_POST['scfl_name']);
            $email = sanitize_email($_POST['scfl_email']);
            $message = sanitize_textarea_field($_POST['scfl_message']);

            $wpdb->insert($table_name, [
                'name' => $name,
                'email' => $email,
                'message' => $message,
                'submitted_at' => current_time('mysql')
            ]);
        }
    }

    public function create_database_table() {
        global $wpdb;
        $table_name = $wpdb->prefix . 'scfl_submissions';

        $charset_collate = $wpdb->get_charset_collate();

        $sql = "CREATE TABLE $table_name (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            name tinytext NOT NULL,
            email varchar(100) NOT NULL,
            message text NOT NULL,
            submitted_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
            PRIMARY KEY  (id)
        ) $charset_collate;";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }

    public function create_admin_menu() {
        add_menu_page(
            'Contact Submissions',
            'Contact Form Logs',
            'manage_options',
            'scfl-submissions',
            [$this, 'display_submissions']
        );
    }

    public function display_submissions() {
        global $wpdb;
        $table_name = $wpdb->prefix . 'scfl_submissions';
        $results = $wpdb->get_results("SELECT * FROM $table_name ORDER BY submitted_at DESC");

        echo '<div class="wrap"><h1>Contact Form Submissions</h1><table class="widefat fixed">';
        echo '<thead><tr><th>Name</th><th>Email</th><th>Message</th><th>Date</th></tr></thead><tbody>';

        foreach ($results as $row) {
            echo '<tr>';
            echo '<td>' . esc_html($row->name) . '</td>';
            echo '<td>' . esc_html($row->email) . '</td>';
            echo '<td>' . esc_html($row->message) . '</td>';
            echo '<td>' . esc_html($row->submitted_at) . '</td>';
            echo '</tr>';
        }

        echo '</tbody></table></div>';
    }
}

new WeengleContactFormLogger();
